
/*

  KLayout Layout Viewer
  Copyright (C) 2006-2007 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#include "laySession.h"
#include "layCellView.h"
#include "tlXMLParser.h"

#include <fstream>

namespace lay
{

Session::Session ()
{

}

void 
Session::fetch (const lay::MainWindow &app)
{
  std::vector <std::string> layout_names;
  LayoutHandle::get_names (layout_names);

  for (std::vector <std::string>::const_iterator l = layout_names.begin (); l != layout_names.end (); ++l) {
    LayoutHandle *lh = LayoutHandle::find (*l);
    if (lh) {
      m_layouts.push_back (SessionLayoutDescriptor ());
      m_layouts.back ().name = *l;
      m_layouts.back ().file_path = lh->filename ();
    }
  }

  printf ("@@@ Session::fetch()\n");

}

void 
Session::restore (lay::MainWindow &app)
{

  printf ("@@@ Session::restore()\n");

}

//  declaration of the session file XML structure
static const tl::XMLStruct <Session>
session_structure ("session", 
  tl::make_element<SessionLayoutDescriptor, std::vector<SessionLayoutDescriptor>::const_iterator, Session> (&Session::begin_layouts, &Session::end_layouts, &Session::add_layout, "layouts", 
    tl::make_member<std::string, SessionLayoutDescriptor> (&SessionLayoutDescriptor::name, "name") + 
    tl::make_member<std::string, SessionLayoutDescriptor> (&SessionLayoutDescriptor::file_path, "file-path")
  )
);

void 
Session::load (const std::string &fn)
{
  tl::XMLFileSource in (fn);

  session_structure.parse (in, *this); 

  if (tl::verbosity () >= 10) {
    tl::info << "Loaded session from " << fn;
  }
}

void 
Session::save (const std::string &fn)
{
  std::ofstream out (fn.c_str ());
  if (! out.good ()) {
    throw tl::Exception (tl::translate ("Unable to write session to file: %s").c_str (), fn.c_str ());
  }
  session_structure.write (out, *this); 

  if (tl::verbosity () >= 10) {
    tl::info << "Saved session to " << fn;
  }
}

}

