
/*

  KLayout Layout Viewer
  Copyright (C) 2006-2007 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#ifndef HDR_laySession
#define HDR_laySession

#include <string>
#include <vector>

namespace lay
{

class MainWindow;

struct SessionLayoutDescriptor
{
  std::string name;
  std::string file_path;
};

/**
 *  @brief This class implements the persistency of the session
 */
class Session
{
public:
  /**
   *  @brief Represents a session
   */
  Session ();

  /**
   *  @brief Copy the current application status to the session
   */
  void fetch (const lay::MainWindow &app);

  /**
   *  @brief Restore the session inside the application
   */
  void restore (lay::MainWindow &app);

  /**
   *  @brief Load the session from a file
   */
  void load (const std::string &filename);

  /**
   *  @brief Save the session to a file
   */
  void save (const std::string &filename);

  //  persistency API
  std::vector<SessionLayoutDescriptor>::const_iterator begin_layouts () const { return m_layouts.begin (); }
  std::vector<SessionLayoutDescriptor>::const_iterator end_layouts () const { return m_layouts.end (); }
  void add_layout (const SessionLayoutDescriptor &l) { m_layouts.push_back (l); }

private:
  std::vector<SessionLayoutDescriptor> m_layouts;
};

}

#endif

